
*****************************
***stochastic dominance violations
*****************************

*set the folder to the one caining the data set

use data_risk.dta


***create per choice variable, and stochastic dominance violation count per person

sort subject equiv_nr
order subject equiv_nr equivalent probability high low

gen violation=0

sort subject equiv_nr
by subject: replace violation = 1 if equivalent[_n+1]<equivalent[_n]

order subject equiv_nr equivalent probability violation high low

sum violation, d

sort subject
by subject: egen number_violations = total(violation)

sum number_violations, d


*****************************
***1-parameter Prelec
*****************************


program define Yaari_Prelec1

args lnf alpha noise

tempvar probhigh high_amount low_amount equivalent weighting_gains utility_prospect ce_calc PTdiff

quietly {
generate double `probhigh' = $ML_y1
generate double `high_amount' = $ML_y2
generate double `low_amount' = $ML_y3
generate double `equivalent' = $ML_y4

generate double `weighting_gains' = exp(-(-ln(`probhigh'))^`alpha')

generate double `utility_prospect' = (`weighting_gains'*`high_amount') + ((1-`weighting_gains')*`low_amount')

generate double `ce_calc' = .
replace `ce_calc' = `utility_prospect'

generate double `PTdiff' = (`ce_calc'-`equivalent')
 
replace `lnf' = ln(normalden(`PTdiff',0,(`noise'*abs(`high_amount'-`low_amount'))))
 
}
end


********aggregate estimation


ml model lf Yaari_Prelec1 (alpha: probability high low equivalent = ) (noise: = ), technique(bfgs) init(alpha:_cons=0.7 noise:_cons=7) maximize iterate(5000)
ml display

estimates store Prelec1


*******************************
**2-parameter Prelec function
*******************************

program define Yaari_switching

args lnf alpha beta noise

tempvar probhigh high_amount low_amount equivalent weighting_gains utility_prospect ce_calc PTdiff

quietly {
generate double `probhigh' = $ML_y1
generate double `high_amount' = $ML_y2
generate double `low_amount' = $ML_y3
generate double `equivalent' = $ML_y4

generate double `weighting_gains' = exp(-`beta'*(-ln(`probhigh'))^`alpha')

generate double `utility_prospect' = (`weighting_gains'*`high_amount') + ((1-`weighting_gains')*`low_amount')

generate double `ce_calc' = .
replace `ce_calc' = `utility_prospect'

generate double `PTdiff' = (`ce_calc'-`equivalent')
 
replace `lnf' = ln(normalden(`PTdiff',0,(`noise'*abs(`high_amount'-`low_amount'))))
 
}
end

************************************************
********aggregate estimation, no heterogeneity


ml model lf Yaari_switching (alpha: probability high low equivalent = ) (beta:  = ) (noise: = ) if sure_amount==20, technique(bfgs) init(alpha:_cons=0.7 beta:_cons=0.7 noise:_cons=7) maximize iterate(5000)
ml display

estimates store Prelec2

***likelihood ratio test

lrtest Prelec1 Prelec2


***graph of Prelec 2 fit

sort probability

tw (scatter mean_weight probability if subject==1, mcolor(dkgreen) msize(large) mlabsize(small) msymbol(triangle) connect(l))/*
*/ (function y=exp(-.702*(-ln(x))^.538), range(0 1) lcolor(red) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(order(1 2 3) label(1 "CE/x") label(2 "Prelec function") label(3 "diagonal") ring (0) rows(5) position(10)) xtitle("p") ytitle("{&pi}(p)") xlab(0(0.05)1) ylab(0(0.1)1) yscale(alt)


tw (scatter mean_weight probability if subject==1, mcolor(dkgreen) msize(large) mlabsize(small) msymbol(triangle) connect(l))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(order(1 2 3) label(1 "CE/x") label(2 "Prelec function") label(3 "diagonal") ring (0) rows(5) position(10)) xtitle("p") ytitle("{&pi}(p)") xlab(0(0.05)1) ylab(0(0.1)1) yscale(alt)



**************************
***********************
***Regression analysis
***********************
**************************


****************************
***Socio-economic factors
****************************

**********************
***basic regression:

local demo "land_size_z elevation_z height_z literate middle_school business female age_z unmarried"
local woreda "Oromia SNNP"

ml model lf Yaari_switching (alpha: probability high low equivalent = `demo' `woreda') (beta:  =  `demo' `woreda') (noise: =  `demo' `woreda'), technique(bfgs) cluster(subject) init(alpha:_cons=0.7 beta:_cons=0.7 noise:_cons=7) maximize iterate(5000)
ml display

estimates store income1




********************
***adding wealth:
drop pc*
pca house house_wall nr_rooms s5q10 houses_owned wc income_comparison light_source
predict pc1 pc2 pc3, score

egen TLU_z=std(Livestock_Tot_HH)


local demo "land_size_z elevation_z height_z literate  middle_school business TLU_z pc1 female age_z unmarried"
local woreda "SNNP Oromia"

ml model lf Yaari_switching (alpha: probability high low equivalent = `demo' `woreda') (beta:  =  `demo' `woreda') (noise: =  `demo'  `woreda'), technique(bfgs) cluster(subject) init(alpha:_cons=0.7 beta:_cons=0.7 noise:_cons=7) maximize iterate(5000)
ml display

estimates store income2



*************************************************
*************************************************
***nonparametric stability analysis
*************************************************
*************************************************

local demo "land_size_z elevation_z literate middle_school business female age_z unmarried"
local woreda "Oromia SNNP"
reg mean_CE `demo' `woreda'  if equiv_nr==1 & elevation>0, robust


forvalues i=1(1)7{
local demo "land_size_z elevation_z literate middle_school business female age_z unmarried"
local woreda "Oromia SNNP"
reg equivalent `demo' `woreda'  if equiv_nr==`i' & elevation>0, robust
}




*************************************************
*************************************************
***EU stability analysis
*************************************************
*************************************************

local demo "land_size_z distance_road_z elevation_z literate middle_school business female age_z unmarried"
local woreda "Oromia SNNP"

ml model lf EU_power (rho: probability high low equivalent = `demo' `woreda') (noise: = `demo' `woreda'), technique(bfgs) cluster(subject) init(rho:_cons=1.3 noise:_cons=0.2) maximize iterate(5000)
ml display

